.. See LICENSE for details

.. highlight:: shell

============
Installation
============


Stable release
--------------

To install Repo Manager, run this command in your terminal:

.. code-block:: console

    $ python -m pip install git+https://gitlab.incoresemi.com/utils/repomanager.git

This is the preferred method to install Repo Manager, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


For Developers
----------------

The sources for Repo Manager can be downloaded from the `GitLab repo`_.

You can clone the repository:

.. code-block:: console

    $ git clone https://gitlab.incoresemi.com/utils/repomanager.git


Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Gitlab repo: https://gitlab.incoresemi.com/utils/repomanager
